<?php

namespace Beo\Story\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Beo\Story\Models\Story;

class StoryPolicy
{

    /**
     * Determine if the given user can view the story.
     *
     * @param UserPolicyInterface $authUser
     * @param Story $story
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Story $story)
    {
        if ($authUser->canDo('story.story.view') && $authUser->isAdmin()) {
            return true;
        }

        return $story->user_id == user_id() && $story->user_type == user_type();
    }

    /**
     * Determine if the given user can create a story.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('story.story.create');
    }

    /**
     * Determine if the given user can update the given story.
     *
     * @param UserPolicyInterface $authUser
     * @param Story $story
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Story $story)
    {
        if ($authUser->canDo('story.story.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $story->user_id == user_id() && $story->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given story.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Story $story)
    {
        return $story->user_id == user_id() && $story->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given story.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Story $story)
    {
        if ($authUser->canDo('story.story.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given story.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Story $story)
    {
        if ($authUser->canDo('story.story.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
